hgext/histedit.py
changeset 30332 318a24b52eeb
parent 30262 bc5d0e6fd9f3
child 30837 f59ab1b752bd
--- a/hgext/histedit.py	Thu Nov 03 17:31:14 2016 -0700
+++ b/hgext/histedit.py	Mon Oct 17 23:16:55 2016 +0200
@@ -1405,12 +1405,12 @@
                        % node.short(missing[0]))
 
 def adjustreplacementsfrommarkers(repo, oldreplacements):
     """Adjust replacements from obsolescense markers
 
     Replacements structure is originally generated based on
     histedit's state and does not account for changes that are
     not recorded there. This function fixes that by adding
-    data read from obsolescense markers"""
+    data read from obsolescence markers"""
     if not obsolete.isenabled(repo, obsolete.createmarkersopt):
         return oldreplacements
@@ -1405,12 +1405,12 @@
 
 def adjustreplacementsfrommarkers(repo, oldreplacements):
-    """Adjust replacements from obsolescense markers
+    """Adjust replacements from obsolescence markers
 
     Replacements structure is originally generated based on